---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:legge:2004-01-09;4
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20040117&codiceRedaz=004G0015&dataVigenza=20251104
dataGU: 20040117
codiceRedaz: 004G0015
dataVigenza: 20251104
---

# ((Disposizioni per favorire e semplificare l'accesso degli utenti e,
in particolare, delle persone con disabilita' agli strumenti
informatici)).

La Camera dei deputati ed il Senato della Repubblica hanno

approvato;

IL PRESIDENTE DELLA REPUBBLICA

Promulga la seguente legge:

## Art. 1.

(Obiettivi e finalita)

1. La Repubblica riconosce e tutela il diritto di ogni persona ad accedere a tutte le fonti di informazione e ai relativi servizi, ivi compresi quelli che si articolano attraverso gli strumenti informatici e telematici.

2. E' tutelato e garantito, in particolare, il diritto di accesso ai servizi informatici e telematici della pubblica amministrazione ((, nonche' alle strutture ed ai servizi aperti o forniti al pubblico attraverso i nuovi sistemi e le tecnologie di informazione e comunicazione in rete)) e ai servizi di pubblica utilita' da parte delle persone con disabilita', in ottemperanza al principio di uguaglianza ai sensi dell'articolo 3 della Costituzione.

## Art. 2. - (Definizioni)

1. Ai fini della presente legge, si intende per:

- a) "accessibilita'": la capacita' dei sistemi informatici ivi inclusi i siti web e le applicazioni mobili, nelle forme e nei limiti consentiti dalle conoscenze tecnologiche, di erogare servizi e fornire informazioni fruibili, senza discriminazioni, anche da parte di coloro che a causa di disabilita' necessitano di tecnologie assistive o configurazioni particolari;
- a-bis) "applicazioni mobili": il software applicativo progettato e sviluppato da parte o per conto dei soggetti erogatori, per essere utilizzato dagli utenti su dispositivi mobili, quali smartphone e tablet; e' escluso il software che controlla tali dispositivi (sistemi operativi mobili) o lo stesso hardware informatico;
- a-ter) "sito Web": insieme strutturato di pagine Web utilizzato per veicolare informazioni o erogare servizi, comunemente definito anche sito internet;
- a-quater) contenuti di extranet o intranet: siti web disponibili soltanto per un gruppo chiuso di persone e non per il pubblico;
- a-quinquies) "soggetti erogatori": i soggetti di cui all'articolo 3, ((commi 1 e 1-bis));
- a-sexies) "dati misurati": i risultati quantificati dell'attivita' di monitoraggio effettuata per verificare la conformita' dei siti web e delle applicazioni mobili dei soggetti erogatori alle prescrizioni in materia di accessibilita' di cui alla presente legge. I dati misurati comprendono informazioni quantitative sul campione di siti web e applicazioni mobili sottoposti a verifiche, tra i quali il numero di siti web e le applicazioni con il numero potenziale di visitatori o utenti, nonche' informazioni quantitative sul livello di accessibilita';
- b) "tecnologie assistive": gli strumenti e le soluzioni tecniche, hardware e software, che permettono alla persona disabile, superando o riducendo le condizioni di svantaggio, di accedere alle informazioni e ai servizi erogati dai sistemi informatici.

## Art. 3. - (Soggetti erogatori)

1. La presente legge si applica alle pubbliche amministrazioni di cui al comma 2 dell'articolo 1 del decreto legislativo 30 marzo 2001, n. 165, e successive modificazioni, agli enti pubblici economici, alle aziende private concessionarie di servizi pubblici, alle aziende municipalizzate regionali, agli enti di assistenza e di riabilitazione pubblici, alle aziende di trasporto e di telecomunicazione a prevalente partecipazione di capitale pubblico e alle aziende appaltatrici di servizi informatici, agli organismi di diritto pubblico ai sensi dell'articolo 2, paragrafo 1, punto 4, della direttiva 2014/24/UE del Parlamento europeo e del Consiglio, del 26 febbraio 2014 nonche' a tutti i soggetti che usufruiscono di contributi pubblici o agevolazioni per l'erogazione dei propri servizi tramite sistemi informativi o internet.

1-bis. La presente legge si applica altresi' ai soggetti giuridici diversi da quelli di cui al comma 1, che offrono servizi al pubblico attraverso siti web o applicazioni mobili, con un fatturato medio, negli ultimi tre anni di attivita', superiore a ((cinquecento)) milioni di euro.

2. Le disposizioni della presente legge in ordine agli obblighi per l'accessibilita' non si applicano ai contenuti che si trovano esclusivamente su dispositivi mobili o programmi utente per dispositivi mobili sviluppati per gruppi chiusi di utenti o per uso specifico in determinati contesti e non disponibili e usati da ampi segmenti di utenti. Le medesime disposizioni non si applicano ai contenuti di extranet o intranet, di cui all'articolo 2, comma 1, lettera a-quater), pubblicati prima del 23 settembre 2019 fino a una loro revisione sostanziale.

## Art. 3-bis. - (( (Principi generali per l'accessibilita'). ))

((

1. I siti web e le applicazioni mobili dei soggetti erogatori, sono accessibili se sono percepibili, utilizzabili, comprensibili e solidi.

2. Sono accessibili i servizi realizzati tramite sistemi informatici, inclusi i siti web e le applicazioni mobili, che presentano i seguenti requisiti:

- a) accessibilita' al contenuto del servizio da parte dell'utente;
- b) fruibilita' delle informazioni offerte, caratterizzata da: 1) facilita' e semplicita' d'uso, assicurando, fra l'altro, che le azioni da compiere per ottenere servizi e informazioni siano sempre uniformi tra loro; 2) efficienza nell'uso, assicurando, fra l'altro, la separazione tra contenuto, presentazione e modalita' di funzionamento delle interfacce, nonche' la possibilita' di rendere disponibile l'informazione attraverso differenti canali sensoriali; 3) efficacia nell'uso e rispondenza alle esigenze dell'utente, assicurando, fra l'altro, che le azioni da compiere per ottenere in modo corretto servizi e informazioni siano indipendenti dal dispositivo utilizzato per l'accesso; 4) soddisfazione nell'uso, assicurando, fra l'altro, l'accesso al servizio e all'informazione senza ingiustificati disagi o vincoli per l'utente.

3. Con le linee guida adottate ai sensi dell'articolo 11, sono individuate le regole tecniche necessarie per garantire il rispetto dei principi e dei requisiti di accessibilita' di cui ai commi 1 e 2.

))

## Art. 3-ter. - (( (Individuazione dell'onere sproporzionato per l'accessibilita' dei siti web e delle applicazioni mobili). ))

((

1. I soggetti erogatori applicano le prescrizioni in materia di accessibilita' previste dalla presente legge sulla base delle linee guida di cui all'articolo 11, salvo che, nei casi di accessibilita' dei siti web e delle applicazioni mobili, cio' imponga un onere sproporzionato.

2. Per onere sproporzionato si intende un onere organizzativo o finanziario eccessivo per i soggetti erogatori ovvero un onere che pregiudica la capacita' degli stessi di adempiere allo scopo prefissato o di pubblicare le informazioni necessarie o pertinenti per i compiti e servizi, pur tenendo conto del probabile beneficio o pregiudizio che ne deriverebbe per i cittadini e, in particolare, per le persone con disabilita'. Non possono costituire, di per se', un onere sproporzionato i tempi occorrenti per sviluppare i siti web ed applicazioni mobili ovvero la necessita' di acquisire le informazioni occorrenti per garantire il rispetto degli obblighi previsti dalla presente legge e dalle linee guida.

3. I soggetti erogatori effettuano, sulla base delle Linee guida di cui all'articolo 11, la valutazione relativa alla sussistenza delle circostanze che determinano l'onere sproporzionato.

4. Nei casi di cui al comma 2, i soggetti erogatori effettuano la dichiarazione di accessibilita' secondo le modalita' di cui all'articolo 3-quater, comma 2, lettera a) ))

## Art. 3-quater. - (( (Dichiarazione di accessibilita'). ))

((

1. I soggetti erogatori, forniscono e aggiornano periodicamente una dichiarazione di accessibilita' particolareggiata, esaustiva e chiara sulla conformita' dei rispettivi siti web e applicazioni mobili alla presente legge.

2. La dichiarazione di accessibilita' comprende, altresi', i seguenti elementi:

- a) indicazione delle parti di contenuto del sito web o dell'applicazione mobile non accessibili per onere sproporzionato ai sensi dell'articolo 3-ter, con le motivazioni che ne giustificano l'inaccessibilita' e l'indicazione di eventuali soluzioni di accessibilita' alternative fornite dai soggetti erogatori;
- b) la descrizione del meccanismo di feedback, e relativo link, istituito per consentire a chiunque di notificare ai soggetti erogatori eventuali difetti dei sistemi informatici, ivi compresi i siti web e le applicazioni mobili, in termini di conformita' ai principi di accessibilita' di cui all'articolo 3-bis e alle prescrizioni in materia di accessibilita' dettate dalle linee guida di cui all'articolo 11, nonche' di richiedere le informazioni non accessibili e l'adeguamento dei sistemi;
- c) il link alla procedura di cui all'articolo 3-quinquies cui e' possibile fare ricorso in caso di risposta insoddisfacente o di mancata risposta, nel termine di trenta giorni, alla notifica o alla richiesta di cui alla lettera b).

3. Il modello di dichiarazione di accessibilita' e' definito con le linee guida di cui all'articolo 11, nel rispetto di quanto stabilito dalla Commissione europea.

4. La dichiarazione di accessibilita' e' fornita in un formato accessibile ed e' pubblicata sul sito web del soggetto erogatore.

5. Per le applicazioni mobili la dichiarazione di accessibilita' e' fornita in un formato accessibile e e' resa accessibile nel sito web del soggetto erogatore che ha sviluppato l'applicazione mobile, unitamente ad altre informazioni disponibili al momento di scaricare l'applicazione.

))

## Art. 3-quinquies. - (( (Procedura di attuazione). ))

((

1. La dichiarazione di accessibilita' e' verificata dall'Agenzia per l'Italia digitale con riferimento alla conformita' al modello di cui all'articolo 3-quater, comma 3, e ai casi di inaccessibilita'.

2. In caso di contestazione sulla dichiarazione di accessibilita' ovvero in caso di esito insoddisfacente del monitoraggio di cui all'articolo 7, comma 1, lettere a) e a-bis), il difensore civico digitale di cui all'articolo 17 del decreto legislativo n. 82 del 2005, decide in merito alla corretta attuazione della presente legge e dispone eventuali misure correttive.

3. Il difensore civico digitale decide, altresi', nei casi di cui all'articolo 3-quater, comma 2, lettera c), su segnalazione dell'utente, disponendo eventuali misure correttive e informando l'Agenzia per l'Italia digitale.

))

## Art. 4.

(Obblighi per l'accessibilita)

1. Nelle procedure svolte dai soggetti di cui all'articolo 3, comma 1, per l'acquisto di beni e per la fornitura di servizi informatici, i requisiti di accessibilita' stabiliti con le linee guida di cui all'articolo 11 sono necessari. La mancata considerazione dei requisiti di accessibilita' o l'eventuale acquisizione di beni o fornitura di servizi non accessibili e' consentita nei casi di cui all'articolo 3, comma 2, ovvero in presenza di un onere sproporzionato nei casi di cui all'articolo 3-ter ed e' adeguatamente motivata. La previsione di cui al secondo periodo si applica anche all'acquisizione di beni o alla fornitura di servizi effettuata dai soggetti di cui all'articolo 3, comma 1-bis.

2. I soggetti di cui all'articolo 3, commi 1 e 1-bis, non possono stipulare, a pena di nullita', contratti per la realizzazione e la modifica di siti web e applicazioni mobili quando non e' previsto che essi rispettino i requisiti di accessibilita' stabiliti dalle linee guida di cui all'articolo 11, fatto salvo quanto previsto dall'articolo 3-ter. I contratti in essere alla data di pubblicazione delle linee guida di cui all'articolo 11, in caso di rinnovo, modifica o novazione, sono adeguati, a pena di nullita', alle disposizioni della presente legge circa il rispetto dei requisiti di accessibilita', con l'obiettivo di realizzare tale adeguamento entro dodici mesi dalla medesima data di adozione delle predette linee guida.

((2-bis. I siti web e le applicazioni mobili realizzati dai soggetti erogatori di cui all'articolo 3, comma 1-bis, sono adeguati alle disposizioni della presente legge in materia di rispetto dei requisiti di accessibilita' entro il 5 novembre 2022.))

((8))

3. La concessione di contributi pubblici a soggetti privati per l'acquisto di beni e servizi informatici destinati all'utilizzo da parte di lavoratori con disabilita' o del pubblico, anche per la predisposizione di postazioni di telelavoro, e' subordinata alla rispondenza di tali beni e servizi ai requisiti di accessibilita' stabiliti dalle linee guida di cui all'articolo 11.

4. I datori di lavoro pubblici e privati pongono a disposizione del dipendente con disabilita' la strumentazione hardware e software e la tecnologia assistiva adeguata alla specifica disabilita', anche in caso di telelavoro, in relazione alle mansioni effettivamente svolte. Ai datori di lavoro privati si applica la disposizione di cui all'articolo 13, comma 1, lettera c), della legge 12 marzo 1999, n. 68. L'Agenzia per l'Italia Digitale stabilisce le specifiche tecniche delle suddette postazioni, nel rispetto della normativa internazionale.

5. I datori di lavoro pubblici provvedono all'attuazione del comma 4 nell'ambito delle specifiche dotazioni di bilancio destinate alla realizzazione e allo sviluppo del sistema informatico.

--------------- AGGIORNAMENTO (8) Il D.Lgs. 27 maggio 2022, n. 82 ha disposto (con l'art. 25, comma 1) che "Le disposizioni del presente decreto hanno effetto a decorrere dal 28 giugno 2025. Fino al 28 giugno 2030 i fornitori di servizi possono continuare a prestare i loro servizi utilizzando prodotti che utilizzavano in modo legittimo prima di tale data per fornire servizi analoghi. I contratti di servizi conclusi prima del 28 giugno 2025 possono essere mantenuti invariati fino alla loro scadenza, ma per non piu' di cinque anni da tale data".

## Art. 5. - (Accessibilita' degli strumenti didattici e formativi)

1. Le disposizioni della presente legge si applicano, altresi', al materiale formativo e didattico utilizzato nelle scuole di ogni ordine e grado.

2. Le convenzioni stipulate tra il Ministero dell'istruzione, dell'universita' e della ricerca e le associazioni di editori per la fornitura di libri alle biblioteche scolastiche prevedono sempre la fornitura di copie su supporto digitale degli strumenti didattici fondamentali, accessibili ((anche)) agli ((alunni con disabilita')) e agli insegnanti di sostegno, nell'ambito delle disponibilita' di bilancio.

## Art. 6.

((ARTICOLO ABROGATO DAL D.LGS. 10 AGOSTO 2018, N. 106))

## Art. 7. - (Compiti amministrativi)

1. ((Nei confronti dei soggetti di cui all'articolo 3, comma 1, l'Agenzia)) per l'Italia digitale:

- a) effettua il monitoraggio dell'attuazione della presente legge;
- a-bis) effettua il monitoraggio periodico sulla conformita' dei siti web e delle applicazioni mobili in materia di accessibilita', avvalendosi anche dell'Istituto superiore delle comunicazioni e delle tecnologie dell'informazione (ISCOM)
- b) vigila sul rispetto da parte delle amministrazioni statali delle disposizioni della presente legge;
- c) indica i soggetti, pubblici o privati, che, oltre ad avere rispettato i requisiti tecnici indicati dalle linee guida di cui all'articolo 11, si sono anche meritoriamente distinti per l'impegno nel perseguire le finalita' indicate dalla presente legge;
- d) promuove, d'intesa con il Ministro per la famiglia e le disabilita' e con il Ministero del lavoro e delle politiche sociali, progetti, iniziative e programmi finalizzati al miglioramento e alla diffusione delle tecnologie assistive e per l'accessibilita';
- e) promuove, con le altre amministrazioni interessate, sentita la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, l'erogazione di finanziamenti finalizzati alla diffusione tra i persone con disabilita' delle tecnologie assistive e degli strumenti informatici, ivi inclusi i siti web e le applicazioni mobili, dotati di configurazioni particolari e al sostegno di progetti di ricerca nel campo dell'innovazione tecnologica per la vita indipendente e le pari opportunita' dei disabili;
- f) favorisce, d'intesa con il Ministro per la famiglia e le disabilita' e con il Ministero del lavoro e delle politiche sociali e con il Ministro per le pari opportunita', lo scambio di esperienze e di proposte fra associazioni di persone con disabilita', associazioni di sviluppatori competenti in materia di accessibilita', amministrazioni pubbliche, operatori economici e fornitori di hardware e software, anche per la proposta di nuove iniziative;
- g) promuove, d'intesa con il Ministro per la famiglia e le disabilita' e con i Ministeri dell'istruzione, dell'universita' e della ricerca e per i beni e le attivita' culturali, iniziative per favorire l'accessibilita' alle opere multimediali, anche attraverso specifici progetti di ricerca e sperimentazione con il coinvolgimento delle associazioni delle persone con disabilita'; sulla base dei risultati delle sperimentazioni sono indicate, con decreto emanato di intesa dai Ministri interessati, le regole tecniche per l'accessibilita' alle opere multimediali;
- h) definisce, d'intesa con il Ministro per la famiglia e le disabilita' e con il Dipartimento della funzione pubblica della Presidenza del Consiglio dei ministri, gli obiettivi di accessibilita' delle pubbliche amministrazioni nello sviluppo dei sistemi informatici, ivi inclusi i siti web e le applicazioni mobili, nonche' l'introduzione delle problematiche relative all'accessibilita' nei programmi di formazione del personale, in conformita' alla legislazione europea vigente;
- h-bis) entro il 23 dicembre 2021 e successivamente ogni tre anni, presenta alla Commissione europea una relazione sugli esiti del monitoraggio sulla conformita' dei siti web e delle applicazioni mobili dei soggetti erogatori inclusi nell'ambito di applicazione della direttiva (UE) 2016/2102, includendo i dati misurati. Il contenuto delle relazioni e' reso pubblico in un formato accessibile.

2. Le regioni, le province autonome e gli enti locali vigilano sull'attuazione da parte dei propri uffici delle disposizioni della presente legge. (1)

-------------- AGGIORNAMENTO (1) La Corte costituzionale con sentenza 4 - 12 aprile 2005, n. 145 (in G.U. 1a s.s. 20/04/2005, n. 16) ha dichiarato l'illegittimita' costituzionale del comma 2 del presente articolo "nella parte in cui prevede che le Province autonome vigilino sull'attuazione da parte dei propri uffici delle disposizioni della legge".

## Art. 8. - (Formazione)

1. Le amministrazioni di cui all'articolo 3, comma 1, nell'ambito delle attivita' di cui al comma 4 dell'articolo 7 del decreto legislativo 30 marzo 2001, n. 165, nonche' dei corsi di formazione organizzati dalla Scuola superiore della pubblica amministrazione, e nell'ambito delle attivita' per l'alfabetizzazione informatica dei pubblici dipendenti di cui all'articolo 27, comma 8, lettera g), della legge 16 gennaio 2003, n. 3, inseriscono tra le materie di studio a carattere fondamentale le problematiche relative all'accessibilita' e alle tecnologie assistive.

2. La formazione professionale di cui al comma 1 e' effettuata con tecnologie accessibili.

3. Le amministrazioni di cui all'articolo 3, comma 1, nell'ambito delle disponibilita' di bilancio, predispongono corsi di aggiornamento professionale sull'accessibilita' ((, ivi inclusi quelli relativi alle modalita' di creazione, gestione ed aggiornamento di contenuti accessibili dei siti web e delle applicazioni mobili)).

## Art. 9.

(Responsabilita)

1. L'inosservanza delle disposizioni della presente legge ((da parte dei soggetti di cui all'articolo 3, comma 1)) e' rilevante ai fini della misurazione e della valutazione della performance individuale dei dirigenti responsabili e comporta responsabilita' dirigenziale e responsabilita' disciplinare ai sensi degli articoli 21 e 55 del decreto legislativo 30 marzo 2001, n. 165, ferme restando le eventuali responsabilita' penali e civili previste dalle norme vigenti.

((

1-bis. L'inosservanza delle disposizioni della presente legge da parte dei soggetti di cui all'articolo 3, comma 1-bis, e' accertata e sanzionata dall'AgID, fermo restando il diritto del soggetto discriminato di agire ai sensi della legge 1° marzo 2006, n. 67. Si osservano, in quanto applicabili, le disposizioni contenute nel capo I, sezioni I e II, della legge 24 novembre 1981, n. 689. Se a seguito dell'istruttoria l'AgID ravvisa violazioni della presente legge, fissa il termine per l'eliminazione delle infrazioni stesse da parte del trasgressore. In caso di inottemperanza alla diffida di cui al periodo precedente, l'AgID applica la sanzione amministrativa pecuniaria fino al 5 per cento del fatturato.

))

## Art. 10.

((ARTICOLO ABROGATO DAL D.LGS. 10 AGOSTO 2018, N. 106))

## Art. 11. - (( (Requisiti tecnici). ))

((

1. L'Agenzia per l'Italia digitale, sentite anche le associazioni maggiormente rappresentative delle persone con disabilita', nonche' quelle del settore industriale coinvolto nella creazione di software per l'accessibilita' di siti web e applicazioni mobili, d'intesa con la Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, emana, in conformita' alle procedure e alle regole tecniche di cui all'articolo 71 del decreto legislativo 7 marzo 2005, n. 82, apposite linee guida con cui, nel rispetto degli atti di esecuzione adottati dalla Commissione europea ai sensi delle direttive sull'accessibilita', sono stabiliti:

- a) i requisiti tecnici per l'accessibilita' degli strumenti informatici, ivi inclusi i siti web e le applicazioni mobili, conformemente ai principi di cui all'articolo 3-bis e ai valori di cui al punto 1), lettera d), numero 3, dell'allegato B al decreto del Ministro per l'innovazione e le tecnologie 8 luglio 2005, pubblicato nella Gazzetta Ufficiale n. 183 dell'8 agosto 2005;
- b) le metodologie tecniche per la verifica dell'accessibilita' degli strumenti informatici, ivi inclusi i siti web e le applicazioni mobili;
- c) il modello della dichiarazione di accessibilita' di cui all'articolo 3-quater;
- d) la metodologia di monitoraggio e valutazione della conformita' degli strumenti informatici, ivi inclusi i siti web e le applicazioni mobili, alle prescrizioni in materia di accessibilita';
- e) le circostanze in presenza delle quali, tenuto conto di quanto previsto dall'articolo 5 della direttiva (UE) 2016/2102, si determina un onere sproporzionato, per cui i soggetti erogatori possono ragionevolmente limitare l'accessibilita' di un sito web o applicazione mobile.

2. Le linee guida sono aggiornate o modificate con la procedura di cui al comma 1.

))

## Art. 12. - (Normative internazionali)

1. ((Le linee guida di cui all'articolo 11 sono emanate)) osservando le linee guida indicate nelle comunicazioni, nelle raccomandazioni e nelle direttive sull'accessibilita' dell'Unione europea, nonche' nelle normative internazionalmente riconosciute e tenendo conto degli indirizzi forniti dagli organismi pubblici e privati, anche internazionali, operanti nel settore.

2. ((COMMA ABROGATO DAL D.LGS. 10 AGOSTO 2018, N. 106)).

